"""
WebDebug Startup file

Command:
	$> webdebug.py [-port <port>]
Where:
	<port> is the optional port number to listen on. Default is SERVER_PORT
	other arguments are ignored.


WebDebug is a web development proxy server that captures and displays HTTP
requests and responses.
Copyright (C) 1999  Paul Clip.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""

### IMPORTS

from WDconst import *
import WDconfig

import sys
import string

### CONSTANTS


USAGE = """
Command:
	$> webdebug.py [-port <port>] [-nokeepalive] [-singlethreaded]
Where:
	<port> is the optional port number to listen on. Default is %d.
	-nokeepalive turns Keep-Alive support off. Default is on.
	-singlethreaded must the server single threaded. Default is multi threaded.
	other arguments are ignored.
""" % WDconfig.SERVER_PORT


### STARTUP SCRIPT


# Parse command line arguments
try:
	index = 1
	while index < len(sys.argv):
		if sys.argv[index] == '-port':
			WDconfig.SERVER_PORT = string.atoi(sys.argv[index+1])
			index = index + 2
		elif sys.argv[index] == '-nokeepalive':
			WDconfig.KEEP_ALIVE = NO
			print "Disabling Keep-Alive"
			index = index + 1
		elif sys.argv[index] == '-singlethreaded':
			WDconfig.SINGLE_THREADED = YES
			WDconfig.KEEP_ALIVE = NO
			print "Running in single threaded mode (automatically disabling Keep-Alive)"
			index = index + 1
		elif sys.argv[index] == '-h' or sys.argv[index] == '-help' or sys.argv[index] == '?':
			print USAGE
			index = index + 1
		else:
			print "Unknown parameter %s" % sys.argv[index]
			index = index + 1
except:
	print "Error parsing arguments\n%s" % USAGE
	sys.exit(-1)

# these imports have to happen after we have modified the configuration options
import WDserver
import WDhandler

# start web debug server
web_debug = WDserver.WDserver( ('', WDconfig.SERVER_PORT) , WDhandler.WDhandler)
print "WebDebug v%s started on port %d" % (VERSION_NUMBER, WDconfig.SERVER_PORT)
web_debug.serve_forever()
